"use strict";
/**
 * Signing Side Frame
 *
 * @private
 */

var _classCallCheck = require("@babel/runtime/helpers/classCallCheck");

var _createClass = require("@babel/runtime/helpers/createClass");

var _possibleConstructorReturn = require("@babel/runtime/helpers/possibleConstructorReturn");

var _getPrototypeOf = require("@babel/runtime/helpers/getPrototypeOf");

var _assertThisInitialized = require("@babel/runtime/helpers/assertThisInitialized");

var _inherits = require("@babel/runtime/helpers/inherits");

var html = require("@cosmic-plus/domutils/es5/html");

var Observable = require("@cosmic-plus/jsutils/es5/observable");

var _require = require("@cosmic-plus/jsutils/es5/misc"),
    timeout = _require.timeout;

var ClickWall = require("./click-wall");

var cosmicLinkIcon = require("../../bundled/cosmic-link.svg");
/**
 * Class
 */


var SideFrame =
/*#__PURE__*/
function (_Observable) {
  _inherits(SideFrame, _Observable);

  function SideFrame(url) {
    var _this;

    _classCallCheck(this, SideFrame);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SideFrame).call(this));
    if (SideFrame.current) SideFrame.current.close();
    SideFrame.current = _assertThisInitialized(_this);
    _this.shadow = makeShadow();
    _this.closeButton = new SideFrame.CloseButton();
    _this.domNode = html.create("iframe", {
      title: "Signing Frame",
      src: url,
      sandbox: "allow-same-origin allow-scripts allow-forms allow-popups",
      hidden: true
    });
    Object.assign(_this.domNode.style, SideFrame.style);
    _this.domNode.style.transform = "translateX(100%)";
    html.append(document.body, _this.closeButton, _this.domNode);

    _this.show();

    return _this;
  }

  _createClass(SideFrame, [{
    key: "show",
    value: function show() {
      var _this2 = this;

      if (!this.domNode.hidden) return; // Timeout is required for transition to play.

      timeout(0).then(function () {
        return _this2.domNode.style.transform = "none";
      });
      html.show(this.closeButton.domNode, this.domNode);
      return this.shadow.enable().then(function () {
        _this2.shadow.onclick = function () {
          return _this2.close();
        };

        _this2.closeButton.domNode.onclick = function () {
          return _this2.close();
        };

        _this2.trigger("show");
      });
    }
  }, {
    key: "hide",
    value: function hide() {
      var _this3 = this;

      if (this.domNode.hidden) return;
      html.hide(this.closeButton.domNode);
      this.domNode.style.transform = "translateX(100%)";
      return this.shadow.disable().then(function () {
        html.hide(_this3.domNode);

        _this3.trigger("hide");
      });
    }
  }, {
    key: "close",
    value: function close() {
      var _this4 = this;

      SideFrame.current = null;
      this.hide().then(function () {
        html.destroy(_this4.domNode);
        html.destroy(_this4.closeButton.domNode);

        _this4.shadow.destroy();

        _this4.trigger("close");

        _this4.destroy();
      });
    }
  }]);

  return SideFrame;
}(Observable);
/**
 * Event
 */


window.addEventListener("message", function (event) {
  var frameWindow = SideFrame.current && SideFrame.current.domNode.contentWindow;

  if (event.source === frameWindow) {
    switch (event.data) {
      case "show":
        SideFrame.current.show();
        break;

      case "hide":
        SideFrame.current.hide();
        break;

      case "close":
        SideFrame.current.close();
        break;
    }
  }
});
/**
 * Frame style
 */

SideFrame.style = {
  position: "fixed",
  zIndex: 1000,
  right: 0,
  top: 0,
  width: "30em",
  maxWidth: "100%",
  height: "100vh",
  border: "0.1em solid hsl(240, 10%, 75%)",
  background: "hsl(240, 40%, 98%)",
  backgroundImage: "url('".concat(cosmicLinkIcon, "')"),
  backgroundRepeat: "no-repeat",
  backgroundPosition: "center",
  backgroundSize: "12em 12em",
  padding: 0,
  transition: "transform 0.4s",
  willChange: "transform"
  /**
   * Closing button
   */

};

SideFrame.CloseButton = function CloseButton() {
  _classCallCheck(this, CloseButton);

  this.domNode = html.create("span", {
    hidden: true
  }, "× Close");
  Object.assign(this.domNode.style, SideFrame.CloseButton.style);
};

SideFrame.CloseButton.style = {
  position: "fixed",
  zIndex: 1001,
  top: "0.1em",
  right: "0.1em",
  color: "hsl(0, 0%, 40%)",
  fontSize: "0.9em",
  fontWeight: "bold",
  cursor: "pointer",
  background: "hsl(0, 0%, 95%)",
  borderBottomLeftRadius: "0.1em",
  padding: "0.1em 0.3em"
  /**
   * Shadow Layer
   */

};

function makeShadow() {
  return new ClickWall({
    scrollbar: "hide",
    opacity: 0.3,
    delay: 400
  });
}
/**
 * Export
 */


module.exports = SideFrame;